/* =========================================================================

NAME: Crop And Resize

AUTHOR: Oleg Butrin (obutrin@indesign.rudtp.ru)
HOMEPAGE: http://indesign.rudtp.ru
DATE  : 15.12.2004 15:43
EDITED: 09.06.2017

============================================================================ */

#target indesign

var iniTIFFCompressions = new Array("JPEG", "None", "LZW", "ZIP");

function imageOption (myImage) {
	if (myImage == null) {
		return null;
	}
	this.filePath = "";
	this.folder = "";
	this.name = "";
	this.type = "";
	this.resolution = "";
	this.effective = "";
	this.mode = "";
	this.angle = "";
	this.bounds = "";
	this.parentAngle = "";
	this.mask = "";
	this.parentBounds = "";
	this.savePath = "";
	this.flatten = "";
	this.autoLevels = "";
	this.autoContrast = "";
	this.sharpAmount = "";
	this.sharpRadius = "";
	this.sharpThreshold = "";
	this.blurRadius = "";
	this.onlyBlack = "";
	this.qualityJPG = "";
	this.compressTIF = "";
	this.intent = "";
	this.dither = "";	
	this.useBPC = "";
	this.useDither = "";
	this.cropPixels = "";
}

function saveOptions(myCounter) {
	var myFolder = new Folder(myTempFolder)
	if (!myFolder.exists) {
		return null;
	}
	var myFile = new File (myTempFolder + "/" + iniSharedFileName + "_" + String(myCounter) + "." + iniSharedFileExt);
	myFile.encoding = 'UTF-8';
	var myResult = myFile.open("w");
	if (!myResult) {
		return null;
	}
	var myString = "";
	for (var field in this) {
		if (typeof(this[field]) != "function") {
			myString += field + " = " + this[field] + "\n";
		}
	}
	myFile.write(myString);
	myFile.close();
	return true;
}
imageOption.prototype.saveOptions = saveOptions

function getScriptPath () {
	var result = null;
	try {
		result = app.activeScript.path;
	} catch (error) {}

	if (result == null) {
		result = File($.fileName).parent;
	}
	return result;
}

function getImages (myObject, myPrevPlaced, myUnEmbedd, myLocked) {
	try {
		var myGraphics = myObject.allGraphics;
		var myLength = myGraphics.length;
	} catch (error) {
		if (myObject.constructor.name == "Image") {
			var myGraphics = new Array();
			myGraphics[0] = myObject;
		} else {
			return null;
		}
	}
	var myResult = new Array();
	var myCount = 0;
	for (myCounter = 0; myCounter < myGraphics.length; myCounter++) {
		try {
			var myFile = new File(myGraphics[myCounter].itemLink.filePath);
		} catch (error) {
			continue;
		}
		
		if (myGraphics[myCounter].constructor.name == "Image") {
			if ((myGraphics[myCounter].parent.locked) && (!myLocked)) {
				continue;
			}
			if (myGraphics[myCounter].itemLink.edited) {
				continue;
			}
			if ((myGraphics[myCounter].itemLink.status == LinkStatus.linkEmbedded)) {
				if (myUnEmbedd) {
					if (myFile.exists) {
						myGraphics[myCounter].itemLink.unembed();
					} else {
						var myUnEmbedFolder = new Folder(myFile.path);
						if (!myUnEmbedFolder.exists) {
							try {
								myUnEmbedFolder.create();
							} catch (err) {
								continue;
							}
						}
						try {
							myGraphics[myCounter].itemLink.unembed(myUnEmbedFolder);
						} catch (err) {
							continue;
						}
					}
				} else {
					continue;
				}
			} else {
				if (myGraphics[myCounter].itemLink.status == LinkStatus.linkOutOfDate) {
					continue;
				}
				if (myGraphics[myCounter].itemLink.status == LinkStatus.linkMissing) {
					continue;
				}
			}
			if (myPrevPlaced) {
				if (myGraphics[myCounter].extractLabel(iniLabelPlaced) != "true") {
					myResult[myCount] = myGraphics[myCounter];
					myCount++;
				}
			} else {
				myResult[myCount] = myGraphics[myCounter];
				myCount++;
			}
		}
	}
	return myResult ; 
}

function getPattern(myDoc, myImg, myNum, myPattern) {
	var myString = myPattern
	myString = myString.replace(iniDocNamePattern, String(getDocNameOnly(myDoc.name)));
	myString = myString.replace(iniImgNamePattern, (getDocNameOnly(myImg.itemLink.name)));
	myString = myString.replace(iniCounterPattern, String(myNum));
	return myString;	
}


function getDocNameOnly (myFileName) {
	var myString = "";
	var myResult = myFileName.lastIndexOf(".");
	if (myResult == -1) {
		myString = myFileName;
	}
	else {
		myString = myFileName.substr(0, myResult);
	}
	return myString;
}

function getPath (myObject, myNum) {
	if (myObject.paths.length < 1) {
		return null;
	}
	var myResult = new Array();
	var myPath = myObject.paths[myNum];
	for (myCount = 0; myCount < myPath.pathPoints.length; myCount++) {
		myResult[myCount] = myPath.pathPoints[myCount].anchor.join("%") + "|" + myPath.pathPoints[myCount].leftDirection.join("%") + "|" + myPath.pathPoints[myCount].rightDirection.join("%") + "|" + myPath.pathPoints[myCount].pointType;
	} 
	return myResult.join("#");
}

function checkUp (myImages) {
	if (myImages == null) {
		return 0;
	}
	myCount = 0;
	for (myCounter = 0; myCounter < myImages.length; myCounter++) {
		if (myImages[myCounter].extractLabel(iniLabel) != "") {
			var myFile = new File(myImages[myCounter].extractLabel(iniLabel));
			if (myFile.exists) {
				myPrevScale = new Array(myImages[myCounter].horizontalScale, myImages[myCounter].verticalScale);
				var myNewImage = myImages[myCounter].parent.place(myFile, undefined, undefined, false);
//~ 				if (myPrevScale[1] < 0) {
//~ 					myNewImage.resize(-100, 100, AnchorPoint.centerAnchor, false, true, false);
//~ 				}

//~ 				if (myPrevScale[0] < 0) {
//~ 					myNewImage.resize(100, -100, AnchorPoint.centerAnchor, false, true, false);
//~ 					myNewImage.parent.fit(FitOptions.centerContent);
//~ 				}

//~ 				$.writeln(myNewImage.rotationAngle);
//~ 				$.writeln(myNewImage.verticalScale);
				if (myNewImage.rotationAngle == 180 && myNewImage.verticalScale + 100 < 1) {
					myNewImage.rotationAngle = 0;
					}
				myNewImage.horizontalScale = 100;
				myNewImage.verticalScale = 100;
				myNewImage.parent.fit(FitOptions.centerContent);
				myNewImage.insertLabel(iniLabelPlaced, "true");
				myCount++;
			}
		}
	}
	return myCount;
}

function removeDataFiles(myFolder) {
	var myFolder = new Folder(myFolder);
	var myFiles = myFolder.getFiles("*." + iniSharedFileExt)
	for (myCounter = 0; myCounter < myFiles.length; myCounter++) {
		myFiles[myCounter].remove();
	}
}

function fixWhiteSpaces (myImg) {
	var myObject = myImg.parent;
	var myImgBounds = myImg.visibleBounds;
	var myObjBounds = myObject.visibleBounds;
	if (myObjBounds[0] < myImgBounds[0]) {
		myObjBounds[0] = myImgBounds[0]
	}
	if (myObjBounds[1] < myImgBounds[1]) {
		myObjBounds[1] = myImgBounds[1]
	}
	if (myObjBounds[2] > myImgBounds[2]) {
		myObjBounds[2] = myImgBounds[2]	
	}
	if (myObjBounds[3] > myImgBounds[3]) {
		myObjBounds[3] = myImgBounds[3]
	}
	myObject.visibleBounds = myObjBounds;
}

with (app) {
	scriptPreferences.version = 4;
	var mySettingFolder = new Folder("~" + "/" + "CropResizeScript");
	var myTempFolder = mySettingFolder;
	if (!mySettingFolder.exists) {
		try {
			mySettingFolder.create();
		} catch (error) {
			alert(error);
			exit();
		}
	}
	var myIniFile = new File (mySettingFolder + "/CR.ini");
	var myInstallIniFile = new File (getScriptPath() + "/CR.ini");
	if (myInstallIniFile.exists) {
		var myResult = myInstallIniFile.copy(myIniFile);
	}
	if (!myIniFile.exists) {
		var myINIString = "";
		myINIString += "var iniScriptName = \"Crop And Resize InDesign\";\n";
		myINIString += "var iniScriptVersion = \"1.7c\";\n"
		myINIString += "var iniLabel = \"NewLink\";\n";
		myINIString += "var iniLabelPlaced = \"PlacedByScript\";\n";
		myINIString += "var iniSharedFileName = \"CRDF\";\n";
		myINIString += "var iniSharedFileExt = \"crdf\";\n";
		myINIString += "var iniManualPPI = 300;\n"
		myINIString += "var iniFilePattern = \"%doc%_%img%_%N%\";\n";
		myINIString += "var iniDocNamePattern = \"%doc%\";\n";
		myINIString += "var iniImgNamePattern = \"%img%\";\n";
		myINIString += "var iniCounterPattern = \"%N%\";\n";
		myINIString += "var iniImageColors = new Array(\"CMYK\", \"Grayscale\", \"LAB\", \"RGB\");\n";
		myINIString += "var iniDestIntents = new Array(\"absolute\", \"perceptual\", \"relative\", \"saturation\");\n";
		myINIString += "var iniDestDithes = new Array(\"diffusion\", \"noise\", \"none\", \"pattern\");\n";
		myINIString += "var iniFileTypes = new Array(\"*.psd\", \"*.tif\", \"*.jpg\");\n";
		myINIString += "var iniMaskName = \"Crop Resize Mask\";\n";
		myINIString += "var iniBoundsName = \"Crop Resize Bounds\";\n";
		myINIString += "var iniLangFile = \"cropresize.ru.slang\";\n";
		myINIString += "var iniInterfaceFile = \"crInterface.ini\";\n";
		myINIString += "\n";
		myINIString += "//Interface variables\n";
		myINIString += "var iniIntResActual = false;\n";
		myINIString += "var iniIntResEffective = false;\n";
		myINIString += "var iniIntResManual = true;\n";
		myINIString += "var iniIntSavePath = true;\n";
		myINIString += "var iniIntConvert = true;\n";
		myINIString += "var iniIntColorMode = 0;\n";
		myINIString += "var iniIntParentFolder = true;\n";
		myINIString += "var iniIntCheckPlacedBefore = true;\n";
		myINIString += "var iniIntDocFolder = false;\n";
		myINIString += "var iniIntChosenFolder = false;\n";
		myINIString += "var iniIntSaveType = 1;\n";
		myINIString += "var iniIntSaveInterface = true;\n";
		myINIString += "var iniIntSavePath = true;\n";
		myINIString += "var iniIntFlatten = false;\n";
		myINIString += "var iniIntAutoLevels = true;\n";
		myINIString += "var iniIntAutoContrast = true;\n";
		myINIString += "var iniIntEnableSharping = false;\n";
		myINIString += "var iniIntUnSharpAmount = 50;\n";
		myINIString += "var iniIntUnSharpRadius = 1;\n";
		myINIString += "var iniIntUnSharpThreshold = 12;\n";
		myINIString += "var iniIntUnembed = true;\n";
		myINIString += "var iniIntUnlock = true;\n";
		myINIString += "var iniIntCorrectBounds = true;\n";
		myINIString += "var iniIntOnlyBlack = true;\n";
		myINIString += "var iniIntJPGQuality = 3;\n";
		myINIString += "var iniIntTIFFCompress = 1;\n";
		myINIString += "var iniIntEnableProfile = true;\n";
		myINIString += "var iniIntDestIntents = 0;\n";
		myINIString += "var iniIntDestDithes = 2;\n";
		myINIString += "var iniIntDestUseDithes = false;\n";
		myINIString += "var iniIntDestUseBPC = true;\n";
		myINIString += "var iniIntDeleteCropPixels = true;\n";
		
		try {
			myIniFile.open("w");
			myIniFile.write(myINIString)
			myIniFile.close();
			eval ("//@include \'" + myIniFile.path + "/" +myIniFile.name + "\';");
		} catch (error) {
			alert("Can\'t write INI file!");
			exit();
		}
	} else {
		eval ("//@include \'" + myIniFile.path + "/" +myIniFile.name + "\';");
	}
	var myLangFile = new File (mySettingFolder + "/" + iniLangFile);
	var myInstallLangFile = new File (getScriptPath() + "/" + iniLangFile);
	if (myInstallLangFile.exists) {
		var myResult = myInstallLangFile.copy(myLangFile);
	}
	if (!myLangFile.exists) {
		var myLANGString = "";
		myLANGString += "var langNoDocuments = \"No documents open!\";\n";
		myLANGString += "var langNotSaved = \"Document is not saved! Save document before run script!\";\n";
		myLANGString += "var langImagesUpdate = \"images updated!\";\n";
		myLANGString += "var langAllDone = \"All done!\";\n";
		myLANGString += "var langRunPhotoshop = \"Run Crop And Resize Photoshop!\";\n";
		myLANGString += "var langRunInDesign = \"Run Crop And Resize InDesign!\";\n";
		myLANGString += "var langNoFindImages = \"Can\'t find no one images for this options!\";\n";
		myLANGString += "var langNoFindImages = \"Can\'t find no one images for this options!\";\n";
		
		myLANGString += "\n";
		myLANGString += "var langCheckPlacedBefore = \"Not process repeatedly\";\n";
		myLANGString += "var langUnEmbedd = \"Process embed\";\n";
		myLANGString += "var langUnLock = \"Procees locked\";\n";
		myLANGString += "var langImageOptions = \"Image options:\";\n";
		myLANGString += "var langSelectImages = \"Process to current:\";\n";
		myLANGString += "var langDocumentImages = \"document images\";\n";
		myLANGString += "var langSpreadImages = \"spread images\";\n";
		myLANGString += "var langPageImages = \"page images\";\n";
		myLANGString += "var langSelectionImages = \"selection images\";\n";
		myLANGString += "var langSelectOptions = \"With pictures to make:\";\n";
		myLANGString += "var langResolutionsImage = \"Set resulotion to:\";\n";
		myLANGString += "var langResolutionActual = \"actual PPI\";\n";
		myLANGString += "var langResolutionEffective = \"effective PPI\";\n";
		myLANGString += "var langResolutionManual = \"manual PPI\";\n";
		myLANGString += "var langSavePath = \"save contour\";\n";
		myLANGString += "var langFlatten = \"flatten Image\";\n";
		myLANGString += "var langConvertImage = \"convert image to:\";\n";
		myLANGString += "var langOtherOptions = \"Other options:\";\n";
		myLANGString += "var langEnableSharping = \"Unsharp Mask:\";\n";
		myLANGString += "var langCorrectBounds = \"correct parent\";\n";
		myLANGString += "var langAutoLevel = \"auto levels\";\n";
		myLANGString += "var langAutoContrast = \"auto contrast\";\n";
		myLANGString += "var langUnSharpAmount = \"amount:\";\n";
		myLANGString += "var langUnSharpRadius = \"radius:\";\n";
		myLANGString += "var langUnSharpThreshold = \"threshold:\";\n";
		myLANGString += "var langOnlyBlack = \"only black channel\";\n";
		myLANGString += "var langJPGQuality = \"jpg quality: \";\n";
		myLANGString += "var langTIFCompression = \"tiff compr:\";\n";
		myLANGString += "var langProfConvert = \"Profile\";\n";
		myLANGString += "var langProfIntent = \"intent:\";\n";
		myLANGString += "var langProfUseBPC = \"use BPC\";\n";
		myLANGString += "var langProfUseDither = \"use dither\";\n";
		myLANGString += "var langDeleteCropPixels = \"Delete Crop Pixels\";\n";
		
		myLANGString += "\n";
		myLANGString += "var langFileOptions = \"File options:\";\n";
		myLANGString += "var langSaveImagesIn = \"Save images in:\";\n";
		myLANGString += "var langFolderParent = \"image parent folder\";\n";
		myLANGString += "var langFolderDocument = \"document folder\";\n";
		myLANGString += "var langFolderChosen = \"chosen folder\";\n";
		myLANGString += "var langFileName = \"File name pattern:\";\n";
		myLANGString += "var langFolder2Save = \"Select folder to save images...\";\n";
		myLANGString += "var langFileResave = \"resave file as:\";\n";
		myLANGString += "var langSaveInterface = \"Save options\";\n";
		myLANGString += "var langNoFolder = \"Folder for saving files not select!\";\n";
		myLANGString += "\n";
		myLANGString += "var langNotOpenWrite = \"Can\'t open file for writting!\";\n";
		myLANGString += "var langNotOpenRead = \"Can\'t open file for reading!\";\n";
		try {
			myLangFile.open("w");
			myLangFile.write(myLANGString)
			myLangFile.close();
			eval ("//@include \'" + myLangFile.path + "/" + myLangFile.name + "\';");
		} catch (error) {
			alert("Can\'t write LANG file!");
			exit();
		}
	} else {
		eval ("//@include \'" + myLangFile.path + "/" + myLangFile.name + "\';");
	}
	var myIntFile = new File (getScriptPath() + "/" + iniInterfaceFile);
	if (myIntFile.exists) {
		eval ("//@include \'" + myIntFile.path + "/" + myIntFile.name + "\';");
	}
	
	if (documents.length < 1) {
		alert(langNoDocuments);
		exit();
	}
	if (selection.length > 0) {
		var myUserSelectedImages = new Array();
		for (SelCounter = 0; SelCounter < selection.length; SelCounter++) {
			var myCountArray = getImages(selection[SelCounter]);
			myUserSelectedImages = myUserSelectedImages.concat(myCountArray);
		}
	} else {
		var myUserSelectedImages = null;
	}
	removeDataFiles(myTempFolder);
	myDoc = activeDocument;
	try {
		var myFullName = myDoc.fullName;
	} catch (err) {
		alert(langNotSaved);
		exit()
	}
	
	var myResult = checkUp(getImages(myDoc, true));
	if (myResult != 0) {
		alert(String(myResult) + " " + langImagesUpdate);
		exit();
	}
	
	var myDialog = dialogs.add({name:iniScriptName + " " + iniScriptVersion})
	with (myDialog) {
		with (dialogColumns.add()) {
			with(dialogRows.add()) {
				with (dialogColumns.add().borderPanels.add().dialogColumns.add()) {
					dialogRows.add().staticTexts.add({staticLabel:langImageOptions});
					with (borderPanels.add().dialogColumns.add()) {
						dialogRows.add().staticTexts.add({staticLabel:langSelectImages});
						var mySelectObject = dialogRows.add().radiobuttonGroups.add();
						with (mySelectObject) {
							radiobuttonControls.add({staticLabel:langDocumentImages, checkedState:true, minWidth:156});
							radiobuttonControls.add({staticLabel:langSpreadImages});
							radiobuttonControls.add({staticLabel:langPageImages});
							if (myUserSelectedImages != null) {
								radiobuttonControls.add({staticLabel:langSelectionImages, checkedState:true});
							}
						}
					}					
					dialogRows.add().staticTexts.add({staticLabel:langFileOptions});
					var mySelectDeleteCropPixels = dialogRows.add().checkboxControls.add({staticLabel:langDeleteCropPixels, checkedState:iniIntDeleteCropPixels, minWidth:154});
					var mySelectUnEmbedd = dialogRows.add().checkboxControls.add({staticLabel:langUnEmbedd, checkedState:iniIntUnembed});
					var mySelectUnLock = dialogRows.add().checkboxControls.add({staticLabel:langUnLock, checkedState:iniIntUnlock});
					var mySelectCheckBefore = dialogRows.add().checkboxControls.add({staticLabel:langCheckPlacedBefore, checkedState:iniIntCheckPlacedBefore});
					with (borderPanels.add().dialogColumns.add()) {
						dialogRows.add().staticTexts.add({staticLabel:langSaveImagesIn});
						var mySelectSaveFolder = dialogRows.add().radiobuttonGroups.add();
						with (mySelectSaveFolder) {
							radiobuttonControls.add({staticLabel:langFolderParent, checkedState:iniIntParentFolder, minWidth:156});
							radiobuttonControls.add({staticLabel:langFolderDocument, checkedState:iniIntDocFolder});
							radiobuttonControls.add({staticLabel:langFolderChosen, checkedState:iniIntChosenFolder});
						}
					}
					with (borderPanels.add().dialogColumns.add()) {
						dialogRows.add().staticTexts.add({staticLabel:langFileName});
						var mySelectFilePattern = dialogRows.add().textEditboxes.add({editContents:iniFilePattern, minWidth:156});
						with (dialogRows.add()) {
							with (dialogColumns.add()) {
								dialogRows.add().staticTexts.add({staticLabel:langFileResave});
							}
							with (dialogColumns.add()) {
								var mySelectReSaveType = dropdowns.add({stringList:iniFileTypes, selectedIndex:iniIntSaveType});
							}
						}
					}
				}
				with (dialogColumns.add().borderPanels.add().dialogColumns.add()) {
					dialogRows.add().staticTexts.add({staticLabel:langSelectOptions});
					with (dialogRows.add()) {
						with (dialogColumns.add()) {
							with (borderPanels.add().dialogColumns.add()) {
								var mySelectResolution = dialogRows.add().staticTexts.add({staticLabel:langResolutionsImage});
								var mySelectResolutionsStatus = dialogRows.add().radiobuttonGroups.add();
								with (mySelectResolutionsStatus) {
									radiobuttonControls.add({staticLabel:langResolutionActual, checkedState:iniIntResActual, minWidth:154});
									radiobuttonControls.add({staticLabel:langResolutionEffective, checkedState:iniIntResEffective});
									radiobuttonControls.add({staticLabel:langResolutionManual, checkedState:iniIntResManual});
								}
								var mySelectManualResolution = dialogRows.add().integerEditboxes.add({editValue:iniManualPPI, minimumValue:10, maximumValue:10000});
							}
							with (borderPanels.add().dialogColumns.add()) {
								var mySelectReColor = dialogRows.add().checkboxControls.add({staticLabel:langConvertImage, checkedState:iniIntConvert});
								var mySelectColors = dialogRows.add().dropdowns.add({stringList:iniImageColors, selectedIndex:iniIntColorMode, minWidth:154});
							}
							dialogRows.add().staticTexts.add({staticLabel:langOtherOptions});
							with (borderPanels.add().dialogColumns.add()) {
								with (dialogRows.add()) {
									with (dialogColumns.add()) {
										dialogRows.add().staticTexts.add({staticLabel:langJPGQuality});
									}
									with (dialogColumns.add()) {
										var mySelectJPGQuality = dialogRows.add().integerEditboxes.add({editValue:iniIntJPGQuality, minWidth:60, minimumValue:0, maximumValue:12});
									}
								}
								with (dialogRows.add()) {
									with (dialogColumns.add()) {
										dialogRows.add().staticTexts.add({staticLabel:langTIFCompression});
									}
									with (dialogColumns.add()) {
										var mySelectTIFCompression = dialogRows.add().dropdowns.add({stringList:iniTIFFCompressions, selectedIndex:iniIntTIFFCompress, minWidth:74});
									}
								}
								var mySelectCorrectBounds = dialogRows.add().checkboxControls.add({staticLabel:langCorrectBounds, checkedState:iniIntCorrectBounds, minWidth:154});
								var mySelectSavePath = dialogRows.add().checkboxControls.add({staticLabel:langSavePath, checkedState:iniIntSavePath, minWidth:154});
								var mySelectFlatten = dialogRows.add().checkboxControls.add({staticLabel:langFlatten, checkedState:iniIntFlatten, minWidth:154});
								var mySelectAutoLevels = dialogRows.add().checkboxControls.add({staticLabel:langAutoLevel, checkedState:iniIntAutoLevels, minWidth:154});
								var mySelectAutoContrast = dialogRows.add().checkboxControls.add({staticLabel:langAutoContrast, checkedState:iniIntAutoContrast, minWidth:154});
							}	
						}
						with (dialogColumns.add()) {
							var mySelectEnableSharping = dialogRows.add().enablingGroups.add({staticLabel:langEnableSharping, checkedState:iniIntEnableSharping});
							var mySelectEnableProfile = dialogRows.add().enablingGroups.add({staticLabel:langProfConvert, checkedState:iniIntEnableProfile});
							
							with (mySelectEnableSharping.dialogColumns.add()) {
								dialogRows.add().staticTexts.add({staticLabel:" ", minWidth:146});
								with (dialogRows.add()) {
									with (dialogColumns.add()) {
										dialogRows.add().staticTexts.add({staticLabel:langUnSharpAmount});
										dialogRows.add().staticTexts.add({staticLabel:langUnSharpRadius});
										dialogRows.add().staticTexts.add({staticLabel:langUnSharpThreshold});
									}
									with (dialogColumns.add()) {
										var mySelectUnSharpAmount = dialogRows.add().percentEditboxes.add({minimumValue:1, maximumValue:500, smallNudge:1, largeNudge:5, editValue:iniIntUnSharpAmount});
										var mySelectUnSharpRadius = dialogRows.add().realEditboxes.add({minimumValue:0.1, maximumValue:250, smallNudge:0.1, largeNudge:1, editValue:iniIntUnSharpRadius});
										var mySelectUnSharpThreshold = dialogRows.add().integerEditboxes.add({minimumValue:1, maximumValue:255, smallNudge:1, largeNudge:5, editValue:iniIntUnSharpThreshold});
									}
								}
								var mySelectOnlyBlack = dialogRows.add().checkboxControls.add({staticLabel:langOnlyBlack, checkedState:iniIntOnlyBlack});
							}						
							with (mySelectEnableProfile.dialogColumns.add()) {
								dialogRows.add().staticTexts.add({staticLabel:" ", minWidth:146});
								with (dialogRows.add()) {
									with (dialogColumns.add()) {
										dialogRows.add().staticTexts.add({staticLabel:langProfIntent});
									}
									with (dialogColumns.add()) {
										var mySelectProfIntents = dialogRows.add().dropdowns.add({stringList:iniDestIntents, selectedIndex:iniIntDestIntents});
									}
								}
								var mySelectProfUseDither = dialogRows.add().checkboxControls.add({staticLabel:langProfUseDither, checkedState:iniIntDestUseDithes});
								var mySelectProfDithers = dialogRows.add().dropdowns.add({stringList:iniDestDithes, selectedIndex:iniIntDestDithes, minWidth:146});
								var mySelectProfUseBPC = dialogRows.add().checkboxControls.add({staticLabel:langProfUseBPC, checkedState:iniIntDestUseBPC});
							}									
						}
					}
				}
			}
			with (dialogRows.add()) {
				with (dialogColumns.add()) {
					var mySelectSaveInterface = dialogRows.add().checkboxControls.add({staticLabel:langSaveInterface, checkedState:iniIntSaveInterface});
				}
				with (dialogColumns.add()) {
					dialogRows.add().staticTexts.add({staticLabel:"   |   "});
				}

				with (dialogColumns.add()) {
					dialogRows.add().staticTexts.add({staticLabel:"\u00A9 Oleg Butrin \u221E http://indesign.rudtp.ru"});
				}
			}
		}
	}
	var myResult = myDialog.show();
	if (!myResult) {
		myDialog.destroy();
		exit();
	}
	if ((mySelectReColor.checkedState) && (mySelectColors.selectedIndex == 2) && (mySelectReSaveType.selectedIndex > 1) ) {
		alert(langNoSaveColorToType);
		exit();
	}
	if (mySelectSaveInterface.checkedState) {
		var myIntString = "";
		myIntString += "var iniIntResActual = " + String(mySelectResolutionsStatus.radiobuttonControls[0].checkedState) + ";\n";
		myIntString += "var iniIntResEffective = " + String(mySelectResolutionsStatus.radiobuttonControls[1].checkedState) + ";\n";
		myIntString += "var iniIntResManual = " + String(mySelectResolutionsStatus.radiobuttonControls[2].checkedState) + ";\n";
		myIntString += "var iniManualPPI = " + String(mySelectManualResolution.editValue) + ";\n";
		myIntString += "var iniIntSavePath = " + String(mySelectSavePath.checkedState) + ";\n";
		myIntString += "var iniIntConvert = " + String(mySelectReColor.checkedState) + ";\n";
		myIntString += "var iniIntColorMode = " + String(mySelectColors.selectedIndex) + ";\n";
		myIntString += "var iniIntCheckPlacedBefore = " + String(mySelectCheckBefore.checkedState) + ";\n";
		myIntString += "var iniIntParentFolder = " + String(mySelectSaveFolder.radiobuttonControls[0].checkedState) + ";\n";
		myIntString += "var iniIntDocFolder = " + String(mySelectSaveFolder.radiobuttonControls[1].checkedState) + ";\n";
		myIntString += "var iniIntChosenFolder = " + String(mySelectSaveFolder.radiobuttonControls[2].checkedState) + ";\n";
		myIntString += "var iniIntSaveType = " + String(mySelectReSaveType.selectedIndex) + ";\n";
		myIntString += "var iniIntSaveInterface = " + String(mySelectSaveInterface.checkedState) + ";\n";
		myIntString += "var iniIntSavePath = " + String(mySelectSavePath.checkedState) + ";\n";
		myIntString += "var iniIntFlatten = " + String(mySelectFlatten.checkedState) + ";\n";
		myIntString += "var iniIntAutoLevels = " + String(mySelectAutoLevels.checkedState) + ";\n";
		myIntString += "var iniIntAutoContrast = " + String(mySelectAutoContrast.checkedState) + ";\n";
		myIntString += "var iniIntEnableSharping = " + String(mySelectEnableSharping.checkedState) + ";\n";
		myIntString += "var iniIntUnSharpAmount = " + String(mySelectUnSharpAmount.editValue) + ";\n";
		myIntString += "var iniIntUnSharpRadius = " + String(mySelectUnSharpRadius.editValue) + ";\n";
		myIntString += "var iniIntUnSharpThreshold = " + String(mySelectUnSharpThreshold.editValue) + ";\n";
		myIntString += "var iniIntUnembed = " + String(mySelectUnEmbedd.checkedState) + ";\n";
		myIntString += "var iniIntUnlock = " + String(mySelectUnLock.checkedState) + ";\n";
		myIntString += "var iniIntCorrectBounds = " + String(mySelectCorrectBounds.checkedState) + ";\n";
		myIntString += "var iniIntOnlyBlack = " + String(mySelectOnlyBlack.checkedState) + ";\n";
		myIntString += "var iniIntJPGQuality = " + String(mySelectJPGQuality.editValue) + ";\n";
		myIntString += "var iniIntTIFFCompress = " + String(mySelectTIFCompression.selectedIndex) + ";\n";
		myIntString += "var iniIntEnableProfile = " + String(mySelectEnableProfile.checkedState) + ";\n";
		myIntString += "var iniIntDestIntents = " + String(mySelectProfIntents.selectedIndex) + ";\n";
		myIntString += "var iniIntDestDithes = " + String(mySelectProfDithers.selectedIndex) + ";\n";
		myIntString += "var iniIntDestUseDithes = " + String(mySelectProfUseDither.checkedState) + ";\n";
		myIntString += "var iniIntDestUseBPC = " + String(mySelectProfUseBPC.checkedState) + ";\n";
		myIntString += "var iniIntDeleteCropPixels = " + String(mySelectDeleteCropPixels.checkedState) + ";\n";
		
		var myIntFile = new File (getScriptPath() + "/" + iniInterfaceFile)
		var myResult = myIntFile.open("w");
		if (myResult) {
			myIntFile.write(myIntString);
			myIntFile.close();		
		}
	}
	switch (mySelectObject.selectedButton) {
		case 0:
			var myObject = myDoc;
			var myImages = getImages(myObject, mySelectCheckBefore.checkedState, mySelectUnEmbedd.checkedState, mySelectUnLock.checkedState);
			break;
		case 1:
			var myObject = activeWindow.activeSpread;
			var myImages = getImages(myObject, mySelectCheckBefore.checkedState, mySelectUnEmbedd.checkedState, mySelectUnLock.checkedState);
			break;
		case 2:
			var myObject = activeWindow.activePage;
			var myImages = getImages(myObject, mySelectCheckBefore.checkedState, mySelectUnEmbedd.checkedState, mySelectUnLock.checkedState);
			break;
		case 3:
			var myObject = selection;
			var myImages = new Array();
			for (SelCounter = 0; SelCounter < selection.length; SelCounter++) {
				var myCountArray = getImages(selection[SelCounter], mySelectCheckBefore.checkedState, mySelectUnEmbedd.checkedState, mySelectUnLock.checkedState);
				myImages = myImages.concat(myCountArray);
			}
			break;
	}
	if (myImages.length < 1) {
		alert(langNoFindImages);
		myDialog.destroy();
		exit();
	}
	if (mySelectSaveFolder.selectedButton == 2) {
		var mySelectedFolder = Folder.selectDialog(langFolder2Save);
		if (!mySelectedFolder) {
			alert(langNoFolder);
			myDialog.destroy();
			exit();
		}
	}
	
	myHU = myDoc.viewPreferences.horizontalMeasurementUnits;
	myVU = myDoc.viewPreferences.verticalMeasurementUnits;
	myDoc.viewPreferences.horizontalMeasurementUnits = MeasurementUnits.points;
	myDoc.viewPreferences.verticalMeasurementUnits = MeasurementUnits.points;

	for (myCounter = 0; myCounter < myImages.length; myCounter++) {
		var myImg = myImages[myCounter];
		var myOptions = new imageOption(myImg);
//   
		myOptions.filePath = myImg.itemLink.filePath;
//  
		switch (mySelectSaveFolder.selectedButton) {
			case 0:
				myOptions.folder = File(myImg.itemLink.filePath).path;
				break;
			case 1:
				myOptions.folder = myDoc.filePath;
				break;
			case 2:
				myOptions.folder = mySelectedFolder;
				break;
		}
		myOptions.cropPixels = mySelectDeleteCropPixels.checkedState;
//  		
		myOptions.name = File.encode(getPattern(myDoc, myImg, myCounter, mySelectFilePattern.editContents));
//  
		myOptions.type = mySelectReSaveType.selectedIndex;
//  
		switch (mySelectResolutionsStatus.selectedButton) {
			case 0:
				myOptions.resolution = myImg.actualPpi;
				break;
			case 1:
				myOptions.resolution = myImg.effectivePpi;
				break;
			case 2:
				myOptions.resolution = mySelectManualResolution.editValue + "," + mySelectManualResolution.editValue;
				break;
		}
//   
		myOptions.actual = myImg.actualPpi;
		myOptions.effective = myImg.effectivePpi;
		myOptions.horizontalScale = myImg.horizontalScale;
		myOptions.verticalScale = myImg.verticalScale;
		if (myImg.parent.locked) {
			var myUnLock = true;
			myImg.parent.locked = false;
		}		
// 
		if (myImg.verticalScale < 0) {
			var myRotateH = true;
			myImg.parent.resize(-100, 100, AnchorPoint.centerAnchor, true, true, false);
		} else {
			var myRotateH = false;
			}
		if (myImg.horizontalScale < 0) {
			var myRotateV = true;
			myImg.parent.resize(100, -100, AnchorPoint.centerAnchor, true, true, false);
		} else {
			var myRotateV = false;
		}
//  
		myOptions.qualityJPG = mySelectJPGQuality.editValue;
		myOptions.compressTIF = mySelectTIFCompression.selectedIndex;
		myOptions.savePath = mySelectSavePath.checkedState;
		myOptions.flatten = mySelectFlatten.checkedState;
		myOptions.autoLevels = mySelectAutoLevels.checkedState;
		myOptions.autoContrast = mySelectAutoContrast.checkedState;
		if (mySelectEnableSharping.checkedState) {
			myOptions.sharpAmount = mySelectUnSharpAmount.editValue;
			myOptions.sharpRadius = mySelectUnSharpRadius.editValue;
			myOptions.sharpThreshold = mySelectUnSharpThreshold.editValue;
			myOptions.onlyBlack = mySelectOnlyBlack.checkedState;
		} else {
			myOptions.sharpAmount = -1;
			myOptions.sharpRadius = -1;
			myOptions.sharpThreshold = -1;
		}
		
		if (mySelectEnableProfile.checkedState) {
			myOptions.intent = mySelectProfIntents.selectedIndex;
			myOptions.dither = mySelectProfDithers.selectedIndex;
			myOptions.useBPC = mySelectProfUseBPC.checkedState;
			myOptions.useDither = mySelectProfUseDither.checkedState;	
		} else {
			myOptions.intent = -1;
			myOptions.dither = -1;
			myOptions.useBPC = false;
			myOptions.useDither = false;		
		}
		
// 		
		if (mySelectReColor.checkedState) {
			myOptions.mode = mySelectColors.selectedIndex;
		} else {
			myOptions.mode = String(-1);
		}
		myOptions.angle = myImg.rotationAngle;
		var myStartRotatingAngle = myImg.parent.rotationAngle;
// 		
		myImg.parent.rotationAngle = myImg.parent.rotationAngle - myImg.rotationAngle;
		if (mySelectCorrectBounds.checkedState && (myImg.parent.rotationAngle % 90 == 0)) {
			fixWhiteSpaces(myImg);
		}
// 
		myOptions.bounds = myImg.geometricBounds;
//  
		myOptions.parentAngle = myImg.parent.rotationAngle;
//   0
		myOptions.mask = getPath(myImg.parent, 0);
//    1
		var myBounds = myImg.parent.geometricBounds;
		var myPathPoints = new Array(Array(myBounds[1], myBounds[0]), Array(myBounds[3], myBounds[0]), Array(myBounds[3], myBounds[2]), Array(myBounds[1], myBounds[2])); 
//  
		myPath = myImg.parent.paths.add({entirePath:myPathPoints});
//  
		myOptions.parentBounds = getPath(myImg.parent, myImg.parent.paths.length - 1);
// 
		myPath.remove();
// 
		myImg.parent.rotationAngle = myStartRotatingAngle;
		if (myRotateH) {
			myImg.parent.resize(-100, 100, AnchorPoint.centerAnchor, true, true, false);
		}
		if (myRotateV) {
			myImg.parent.resize(100, -100, AnchorPoint.centerAnchor, true, true, false);
		}
		if (myUnLock) {
			myImg.parent.locked = true;
		}
		myImg.insertLabel(iniLabel, String(myOptions.folder + "/" + myOptions.name + iniFileTypes[mySelectReSaveType.selectedIndex]).replace("*", ""));
		var myResult = myOptions.saveOptions(myCounter);
		if (!myResult) {
			alert(langNotOpenWrite);
			exit();
		}
	}
	myDoc.viewPreferences.horizontalMeasurementUnits = myHU;
	myDoc.viewPreferences.verticalMeasurementUnits = myVU;
	alert (langAllDone + "\n" + langRunPhotoshop);
	myDialog.destroy();
	exit();
}                                                                                               