/* =========================================================================

NAME: Crop And Resize

AUTHOR: Oleg Butrin (obutrin@indesign.rudtp.ru)
HOMEPAGE: http://indesign.rudtp.ru
DATE  : 15.12.2004 15:43
EDITED: 09.06.2017

============================================================================ */
#target photoshop

var iniPath = new Folder("~" + "/" + "CropResizeScript");
var myTempFolder = iniPath;

var iniImageColorsValue = new Array(ChangeMode.CMYK, ChangeMode.GRAYSCALE, ChangeMode.LAB, ChangeMode.RGB);
var iniImageColorsProfile = new Array("Working CMYK", "Working Gray", "Lab Color", "Working RGB");
var iniTIFFCompressions = new Array(TIFFEncoding.JPEG, TIFFEncoding.NONE, TIFFEncoding.TIFFLZW, TIFFEncoding.TIFFZIP);
var iniIntents = new Array(Intent.ABSOLUTECOLORIMETRIC, Intent.PERCEPTUAL, Intent.RELATIVECOLORIMETRIC, Intent.SATURATION);
var iniDithers = new Array(Dither.DIFFUSION, Dither.NOISE, Dither.NONE, Dither.PATTERN);

function imageOption () {
	this.filePath = "";
	this.folder = "";
	this.name = "";
	this.type = "";
	this.resolution = "";
	this.effective = "";
	this.mode = "";
	this.angle = "";
	this.bounds = "";
	this.parentAngle = "";
	this.mask = "";
	this.parentBounds = "";
	this.savePath = "";
	this.flatten = "";
	this.autoLevels = "";
	this.autoContrast = "";
	this.sharpAmount = "";
	this.sharpRadius = "";
	this.sharpThreshold = "";
	this.onlyBlack = "";
	this.qualityJPG = "";
	this.compressTIF = "";
	this.intent = "";
	this.useBPC = "";
	this.useDither = "";
	this.dither = "";
	this.cropPixels = "";
}


function loadOptions (myFile) {
	myFile.encoding = 'UTF-8';
	var myResult = myFile.open("r");
	if (!myResult) {
		return null;
	}
	var myArray = new Array();
	var myCounter = 0
	while (!myFile.eof) {
		myArray[myCounter] = myFile.readln().split(" = ");
		myCounter++;
	}
	myFile.close();
	for (myCounter = 0; myCounter < myArray.length; myCounter++) {
		this[String(myArray[myCounter][0])] = String(myArray[myCounter][1]);
	}
	return true;
}
imageOption.prototype.loadOptions = loadOptions;

function setType () {
	this.filePath = String(this.filePath);
	this.folder = String(this.folder);
	this.name = String(this.name);
	this.type = Number(this.type);
	
	var myArray = this.resolution.split(",");
	this.resolution = Number(myArray[0]);
	
	var myArray = this.effective.split(",");
	this.effective = Number(myArray[0]);
	var myArray = this.actual.split(",");
	this.actual = Number(myArray[0]);
	this.mode = Number(this.mode);
	this.angle = Number(this.angle);
	
	var myArray = this.bounds.split(",");
	this.bounds = Array(Number(myArray[0]), Number(myArray[1]), Number(myArray[2]), Number(myArray[3]));;
	this.parentAngle = Number(this.parentAngle);
	this.mask = String(this.mask);
	this.parentBounds = String(this.parentBounds);
	
	this.savePath = (this.savePath == "true" ? true : false);
	this.flatten = (this.flatten == "true" ? true : false);
	this.autoLevels = (this.autoLevels == "true" ? true : false);
	this.autoContrast = (this.autoContrast == "true" ? true : false);
	this.cropPixels = (this.cropPixels == "true" ? true : false);
	
	this.qualityJPG = Number(this.qualityJPG);
	this.compressTIF = Number(this.compressTIF);
	
	this.sharpAmount = Number(this.sharpAmount);
	this.sharpRadius = Number(this.sharpRadius);
	this.sharpThreshold = Number(this.sharpThreshold);
	this.onlyBlack = (this.onlyBlack == "true" ? true : false);
	
	this.intent = Number(this.intent);
	this.dither = Number(this.dither);
	this.useBPC = (this.useBPC == "true" ? true : false);
	this.useDither = (this.useDither == "true" ? true : false);
	
	this.horizontalScale = Number(this.horizontalScale);
	this.verticalScale = Number(this.verticalScale);
}
imageOption.prototype.setType = setType;

function getExtension(myFile) {
	var myString = myFile.name;
	var myFind = myString.lastIndexOf(".");
}

function getPath(myString, myObjectCoords) {
	var mySubPath = new Array();
	var myPoints = new Array();
	myObjectCoords[0] = Number(myObjectCoords[0]);
	myObjectCoords[1] = Number(myObjectCoords[1]);
	var myPathPointString = myString.split("#");
	for (myCounter = 0; myCounter < myPathPointString.length; myCounter++) {
		var myPData = myPathPointString[myCounter].split("|");
		var myPDataAnchor = myPData[0].split("%");
		var myPDataRightDirection = myPData[1].split("%");
		var myPDataLeftDirection = myPData[2].split("%");
		
		myPoints[myCounter] = new PathPointInfo;
		myPoints[myCounter].anchor = new Array(Number(myPDataAnchor[0]) - myObjectCoords[1], Number(myPDataAnchor[1]) - myObjectCoords[0]);
		myPoints[myCounter].leftDirection = new Array(Number(myPDataLeftDirection[0]) - myObjectCoords[1], Number(myPDataLeftDirection[1]) - myObjectCoords[0]);
		myPoints[myCounter].rightDirection = new Array(Number(myPDataRightDirection[0]) - myObjectCoords[1], Number(myPDataRightDirection[1]) - myObjectCoords[0]);
		switch (myPData[3]) {
			case "1818848869":
				myPoints[myCounter].kind = PointKind.CORNERPOINT;
				break;
			case "1936553064":
				myPoints[myCounter].kind = PointKind.SMOOTHPOINT;
				break;
			case "1668443762":
				myPoints[myCounter].kind = PointKind.CORNERPOINT;
				break;
		}
	}
	mySubPath[0] = new SubPathInfo();
	mySubPath[0].operation = ShapeOperation.SHAPEXOR;
	mySubPath[0].closed = true;
	mySubPath[0].entireSubPath = myPoints;
	return mySubPath;
}

function getExifRotation(myDoc) {
	var myExifRotation = 0;
	var myExifData = myDoc.info.exif;
	for (myCounter = 0; myCounter < myExifData.length; myCounter++) {
		if (myExifData[myCounter][0] == "Orientation") {
			myExifRotation = String(myExifData[myCounter][1]).replace("Rotate ", "");
			myExifRotation = Number(myExifRotation);
			break;
		}
	}
	if (isNaN(myExifRotation)) {
		return 0;
	} else {
		return -myExifRotation;
	}
	
}

with (app) {

//Change path here!!!
	var myIniFile = new File (iniPath + "/CR.ini");
	if (!myIniFile.exists) {
		alert("Can\'t find ini file!");
		exit ();
	} else {
		eval ("//@include \'" + iniPath + "/" + "CR.ini" + "\';");
	}
	var myLangFile = new File (iniPath + "/" + iniLangFile);
	if (!myLangFile.exists) {
		alert("Can\'t find lang file!");
		exit ();
	} else {
		eval ("//@include \'" + iniPath + "/" + iniLangFile + "\';");
	}	

	var startRulerUnits = app.preferences.rulerUnits;
	var startTypeUnits = app.preferences.typeUnits;
	var startDisplayDialogs = app.displayDialogs;
	app.preferences.rulerUnits = Units.POINTS;
	app.preferences.typeUnits = TypeUnits.POINTS;
	app.displayDialogs = DialogModes.NO;

	var myFolder = myTempFolder;
	var myFiles = myFolder.getFiles("*." + iniSharedFileExt)
	for (FileCounter = 0; FileCounter < myFiles.length; FileCounter++) {
		var myData = new imageOption();
		var myResult = myData.loadOptions(myFiles[FileCounter]);
		if (!myResult) {
			alert(langNotOpenRead);
			exit();
		}
		myData.setType();
		var myDoc = open(File(myData.filePath));
		// myDoc.rotateCanvas(getExifRotation(myDoc));
		if (myData.horizontalScale < 0) {
			myFlipH = true;
			myData.horizontalScale = -myData.horizontalScale;
		} else {
			myFlipH = false;
		}
		if (myData.verticalScale < 0) {
			var myFlipV = true
			myData.verticalScale = -myData.verticalScale;
		} else {
			myFlipV = false;
		}
		if (myData.actual != myDoc.resolution) {
			myDoc.resizeImage(undefined, undefined, myData.actual, ResampleMethod.NONE);
		}
		
		myDoc.resizeImage(UnitValue(myData.horizontalScale, "%"), UnitValue(myData.verticalScale, "%"), myData.effective)
		myDoc.resizeImage(undefined, undefined, myData.resolution, ResampleMethod.BICUBIC);		
		try {
			var myPrevMask = myDoc.pathItems.getByName(iniMaskName);
			myPrevMask.remove();
		} catch (err) {
			
		}
		try {
			myPrevBounds = myDoc.pathItems.getByName(iniBoundsName);
			myPrevBounds.remove();
		} catch (err) {
			
		}
		var myPath = myDoc.pathItems.add(iniMaskName, getPath(myData.mask, myData.bounds));
		var myBounds = myDoc.pathItems.add(iniBoundsName, getPath(myData.parentBounds, myData.bounds));
		var myCropTop = myBounds.subPathItems[0].pathPoints[0].anchor;
		var myCropBottom = myBounds.subPathItems[0].pathPoints[2].anchor;
		var myCrop = new Array(myCropTop[0], myCropTop[1], myCropBottom[0], myCropBottom[1]);
		
		if (myData.cropPixels) {
			myDoc.crop(myCrop);
		} else {
			var idCrop = charIDToTypeID( "Crop" );
			var desc7 = new ActionDescriptor();
			var idT = charIDToTypeID( "T   " );
			var desc8 = new ActionDescriptor();
			var idTop = charIDToTypeID( "Top " );
			var idRlt = charIDToTypeID( "#Rlt" );
			desc8.putUnitDouble( idTop, idRlt, myCropTop[0] );
			var idLeft = charIDToTypeID( "Left" );
			var idRlt = charIDToTypeID( "#Rlt" );
			desc8.putUnitDouble( idLeft, idRlt, myCropTop[1] );
			var idBtom = charIDToTypeID( "Btom" );
			var idRlt = charIDToTypeID( "#Rlt" );
			desc8.putUnitDouble( idBtom, idRlt, myCropBottom[1] );
			var idRght = charIDToTypeID( "Rght" );
			var idRlt = charIDToTypeID( "#Rlt" );
			desc8.putUnitDouble( idRght, idRlt, myCropBottom[0] );
			var idRctn = charIDToTypeID( "Rctn" );
			desc7.putObject( idT, idRctn, desc8 );
			var idAngl = charIDToTypeID( "Angl" );
			var idAng = charIDToTypeID( "#Ang" );
			desc7.putUnitDouble( idAngl, idAng, 0.000000 );
			var idDlt = charIDToTypeID( "Dlt " );
			desc7.putBoolean( idDlt, false );
			var idcropAspectRatioModeKey = stringIDToTypeID( "cropAspectRatioModeKey" );
			var idcropAspectRatioModeClass = stringIDToTypeID( "cropAspectRatioModeClass" );
			var idunconstrained = stringIDToTypeID( "unconstrained" );
			desc7.putEnumerated( idcropAspectRatioModeKey, idcropAspectRatioModeClass, idunconstrained );
			executeAction( idCrop, desc7, DialogModes.NO );
		}

		if (!myData.savePath) {
			myPath.remove();
		}
		if (myFlipH) {
			myDoc.flipCanvas(Direction.VERTICAL);			
		}
		if (myFlipV) {
			myDoc.flipCanvas(Direction.HORIZONTAL);
		}
		myBounds.remove();
		if (myData.mode != -1) {
			if (myData.intent = -1) {
				myDoc.changeMode(iniImageColorsValue[myData.mode])
			} else {
				try  {
					myDoc.convertProfile(iniImageColorsProfile[myData.mode], iniIntents[myData.intent], myData.useBPC, myData.useDither, iniDithers[myData.dither]);
				} catch (error) {
					
				}
			}
		}
		if (myData.flatten) {
			try {
				myDoc.flatten();
			} catch (err) {
				
			}
		}
		for (myCount = 0; myCount < myDoc.artLayers.length; myCount++) {
				var myLayer = myDoc.artLayers[myCount];
				if (myData.autoContrast) {
					try {
						myLayer.autoContrast();
					} catch (error) {
					
					}
				}
				if (myData.autoLevels) {
					try {
						myLayer.autoLevels();
					} catch (error) {
					
					}
				}
				if ((myData.sharpAmount != -1) && (myData.sharpRadius != -1) && (myData.sharpThreshold != -1)) {
					if (myData.onlyBlack) {
						switch (myDoc.mode) {
							case DocumentMode.CMYK:
								myDoc.activeChannels = new Array (myDoc.channels.getByName("Black"));
								try {
									myLayer.applyUnSharpMask(myData.sharpAmount, myData.sharpRadius, myData.sharpThreshold);
								} catch (error) {
								
								}
								break;
							case DocumentMode.GRAYSCALE:
								myDoc.activeChannels = new Array (myDoc.channels.getByName("Gray"));
								try {
									myLayer.applyUnSharpMask(myData.sharpAmount, myData.sharpRadius, myData.sharpThreshold);
								} catch (error) {
								
								}
								break;
						}
					} else {
						try {
							myLayer.applyUnSharpMask(myData.sharpAmount, myData.sharpRadius, myData.sharpThreshold);
						} catch (error) {
					
						}
					}
				}
			}
		switch (myData.type) {
			case 0:
				var mySaveOption = new PhotoshopSaveOptions;
				var myNewFileName = new File (myData.folder + "/"+ File.decode(myData.name) + iniFileTypes[myData.type].replace("*", ""));
				break;
			case 1:
				var mySaveOption = new TiffSaveOptions;
				mySaveOption.imageCompression = iniTIFFCompressions[myData.compressTIF];
				if (myData.compressTIF == 0) {
					mySaveOption.jpegQuality = myData.qualityJPG;
				}				
				var myNewFileName = new File (myData.folder + "/"+ File.decode(myData.name) + iniFileTypes[myData.type].replace("*", ""));
				break;
			case 2:
				var mySaveOption = new JPEGSaveOptions;
				mySaveOption.quality = myData.qualityJPG;
				var myNewFileName = new File (myData.folder + "/"+ File.decode(myData.name) + iniFileTypes[myData.type].replace("*", ""));
				break;
		}
		myDoc.saveAs(myNewFileName, mySaveOption, true, Extension.LOWERCASE);
		myDoc.close(SaveOptions.DONOTSAVECHANGES);
	}
	
	
	app.preferences.rulerUnits = startRulerUnits;
	app.preferences.typeUnits = startTypeUnits;
	app.displayDialogs = startDisplayDialogs;
	alert(langAllDone + "\n" + langRunInDesign);
}